@@ -12,6 +12,7 @@ import inspect
 
 from copy import copy
 from mtools import __version__
+from datetime import timedelta
 
 try:
     import matplotlib.pyplot as plt
@@ -50,8 +51,9 @@ class MPlotQueriesTool(LogFileTool):
         self.argparser.add_argument('--overlay', action='store', nargs='?', default=None, const='add', choices=['add', 'list', 'reset'], help="create combinations of several plots. Use '--overlay' to create an overlay (this will not plot anything). The first call without '--overlay' will additionally plot all existing overlays. Use '--overlay reset' to clear all overlays.")
         self.argparser.add_argument('--type', action='store', default='scatter', choices=self.plot_types.keys(), help='type of plot (default=scatter with --yaxis duration).')        
         self.argparser.add_argument('--title', action='store', default=None, help='change the title of the plot (default=filename(s))')        
-        self.argparser.add_argument('--group', help="specify value to group on. Possible values depend on type of plot. All basic plot types can group on 'namespace', 'operation', 'thread', range and histogram plots can additionally group on 'log2code'. The group can also be a regular expression.")
+        self.argparser.add_argument('--group', help="specify value to group on. Possible values depend on type of plot. All basic plot types can group on 'namespace', 'operation', 'thread', 'pattern', range and histogram plots can additionally group on 'log2code'. The group can also be a regular expression.")
         self.argparser.add_argument('--group-limit', metavar='N', type=int, default=None, help="specify an upper limit of the number of groups. Groups are sorted by number of data points. If limit is specified, only the top N will be listed separately, the rest are grouped together in an 'other' group")
+        self.argparser.add_argument('--optime-start', action='store_true', default=False, help="plot operations with a duration when they started instead (by subtracting the duration). The default is to plot them when they finish (at the time they are logged).")
 
         self.legend = None
 
@@ -131,11 +133,22 @@ class MPlotQueriesTool(LogFileTool):
             for i, line in enumerate(logfile):
                 # create LogLine object
                 logline = LogLine(line)
+
+                # adjust times if --optime-start is enabled
+                if self.args['optime_start'] and logline.duration:
+                    # create new variable end_datetime in logline object and store starttime there
+                    logline.end_datetime = logline.datetime 
+                    logline._datetime = logline._datetime - timedelta(milliseconds=logline.duration)
+                    logline._datetime_calculated = True
+
                 if not start:
                     start = logline.datetime
 
                 if logline.datetime:
-                    end = logline.datetime
+                    if self.args['optime_start'] and hasattr(logline, 'end_datetime'):
+                        end = logline.end_datetime
+                    else:
+                        end = logline.datetime
 
                 # update progress bar every 1000 lines
                 if self.progress_bar_enabled and (i % 1000 == 0) and logline.datetime:
@@ -358,15 +371,17 @@ class MPlotQueriesTool(LogFileTool):
         if xlim_max < xlim_min:
             raise SystemExit('no data to plot.')
 
+        xlabel = 'time'
         ylabel = ''
         for i, plot_inst in enumerate(sorted(self.plot_instances, key=lambda pi: pi.sort_order)):
             self.artists.extend(plot_inst.plot(axis, i, len(self.plot_instances), (xlim_min, xlim_max) ))
+            if hasattr(plot_inst, 'xlabel'):
+                xlabel = plot_inst.xlabel
             if hasattr(plot_inst, 'ylabel'):
                 ylabel = plot_inst.ylabel
-            
         self.print_shortcuts()
 
-        axis.set_xlabel('time')
+        axis.set_xlabel(xlabel)
         axis.set_xticklabels(axis.get_xticks(), rotation=90, fontsize=10)
         axis.xaxis.set_major_formatter(DateFormatter('%b %d\n%H:%M:%S'))
 
